Index: tests/lib/async/zone_future_run_async_test.dart |
diff --git a/tests/lib/async/zone_future_run_async_test.dart b/tests/lib/async/zone_future_run_async_test.dart |
index ddfac1850be2e08c1545e4bf2e4e76947c54e701..32a23c1a9880a5eb867e7694139c2a542472c305 100644 |
--- a/tests/lib/async/zone_future_run_async_test.dart |
+++ b/tests/lib/async/zone_future_run_async_test.dart |
@@ -10,8 +10,8 @@ main() { |
asyncStart(); |
Completer done = new Completer(); |
- // Make sure that the zones use the runAsync of their zones. |
- int runAsyncCount = 0; |
+ // Make sure that the zones use the scheduleMicrotask of their zones. |
+ int scheduleMicrotaskCount = 0; |
Completer completer; |
Completer completer2; |
Future future; |
@@ -23,9 +23,9 @@ main() { |
completer2.complete(-499); |
future = new Future.value(42); |
future2 = new Future.error(11); |
- }, onRunAsync: (f) { |
- runAsyncCount++; |
- runAsync(f); |
+ }, onScheduleMicrotask: (f) { |
+ scheduleMicrotaskCount++; |
+ scheduleMicrotask(f); |
}); |
int openCallbackCount = 0; |
@@ -58,7 +58,7 @@ main() { |
}); |
done.future.whenComplete(() { |
- Expect.equals(4, runAsyncCount); |
+ Expect.equals(4, scheduleMicrotaskCount); |
asyncEnd(); |
}); |
} |